## Summary

Brief description of what this PR does.

## Changes

-
-

## Test Plan

- [ ] `uv run pytest` passes
- [ ] `uv run ruff check src/ tests/` passes
- [ ] `uv run pre-commit run --all-files` passes
- [ ] Tested manually (describe what you tested)
